# coding: utf-8

"""
    Connect API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: v1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class SessionFailCode(str, Enum):
    """
    SessionFailCode
    """

    """
    allowed enum values
    """
    SESSIONFAILNONE = 'SessionFailNone'
    SESSIONFAILINTERNAL = 'SessionFailInternal'
    SESSIONFAILVERIFICATIONFAILED = 'SessionFailVerificationFailed'
    SESSIONFAILAUTHENTICATION = 'SessionFailAuthentication'
    SESSIONFAILEXPIRED = 'SessionFailExpired'
    SESSIONFAILUSERCANCELED = 'SessionFailUserCanceled'
    SESSIONFAILRPCANCELED = 'SessionFailRpCanceled'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of SessionFailCode from a JSON string"""
        return cls(json.loads(json_str))


